--[[

   "Factions and standing requirements" management
   
--]]



-------------------------------------------------------------------------------
-- PURPOSE
--    Get Faction id in database or add Faction to DB if not registered
--
-- PARAMETERS
--    faction name
--
-- RETURNS
--    faction id, or 0 if an error occured
--
-------------------------------------------------------------------------------

function BoC_Factions_GetFactionId( faction_name )

	local faction_id = 0

	for index = 1, table.getn( BookOfCrafts_Data.Factions ) do
	
		if( BookOfCrafts_Data.Factions[index]==faction_name ) then
			faction_id = index
			break
		end
		
	end
	
	-- Faction is registered if it is not found
	if( faction_id==0 ) then
		faction_id = table.getn( BookOfCrafts_Data.Factions )+1
		BookOfCrafts_Data.Factions[faction_id] = faction_name
	end
	
	return faction_id
end



-------------------------------------------------------------------------------
-- PURPOSE
--    Scan current character reputation levels
--
-- REMARKS
--    From WowWiki: http://www.wowwiki.com/API_GetFactionInfo
--    
--    Standing values:
--       0 - Unknown 
--       1 - Hated 
--       2 - Hostile 
--       3 - Unfriendly 
--       4 - Neutral 
--       5 - Friendly 
--       6 - Honored 
--       7 - Revered 
--       8 - Exalted 
--
--    These values are defined globaly by the FACTION_STANDING_LABEL(x)
--    variables, locale specific. It's better to use them instead of relying
--    on the hardcoded values above.
-------------------------------------------------------------------------------

function BoC_Factions_Scan()

	--BoC_ChatMsg( "Factions scan....", true )

	for faction_id=1, GetNumFactions() do
	
		faction_name, desc, standing_id, bottom_val, top_val, earned_val, at_war, can_toggle_at_war, is_header = GetFactionInfo(faction_id)
		if( not is_header ) then
			faction_id = BoC_Factions_GetFactionId( faction_name )
			BookOfCrafts_Data.Characters[BC_char_index].Standings[faction_id] = standing_id
		end	
		
	end
	
end



-------------------------------------------------------------------------------
-- PURPOSE
--    Scan current character reputation levels
--
-- REMARKS:
--    GlobalStrings.lua contains following values
--
--    FACTION_STANDING_LABEL1 = "Hated"        
--    FACTION_STANDING_LABEL1_FEMALE = "Hated" 
--    FACTION_STANDING_LABEL2 = "Hostile"
--    FACTION_STANDING_LABEL2_FEMALE = "Hostile" 
--    FACTION_STANDING_LABEL3 = "Unfriendly"
--    FACTION_STANDING_LABEL3_FEMALE = "Unfriendly"
--    FACTION_STANDING_LABEL4 = "Neutral" 
--    FACTION_STANDING_LABEL4_FEMALE = "Neutral" 
--    FACTION_STANDING_LABEL5 = "Friendly" 
--    FACTION_STANDING_LABEL5_FEMALE = "Friendly"
--    FACTION_STANDING_LABEL6 = "Honored"
--    FACTION_STANDING_LABEL6_FEMALE = "Honored" 
--    FACTION_STANDING_LABEL7 = "Revered" 
--    FACTION_STANDING_LABEL7_FEMALE = "Revered" 
--    FACTION_STANDING_LABEL8 = "Exalted" 
--    FACTION_STANDING_LABEL8_FEMALE = "Exalted"
--
-------------------------------------------------------------------------------

function BoC_Factions_GetStandingId( standing_name )
	
	for index=1, 8 do
		if( (standing_name==getglobal("FACTION_STANDING_LABEL"..index)) or (standing_name==getglobal("FACTION_STANDING_LABEL"..index.."_FEMALE")) ) then
			return index
		end
	end
	
	return 0
end



-------------------------------------------------------------------------------
-- PURPOSE
--    Build BC_SKILL_STANDINGS string, used to validate faction requirements
--
-------------------------------------------------------------------------------
--[[
function BoC_Factions_Init()
	BC_SKILL_STANDINGS = "|"
	for index=1, 8 do
		BC_SKILL_STANDINGS = BC_SKILL_STANDINGS..getglobal("FACTION_STANDING_LABEL"..index).."|"..getglobal("FACTION_STANDING_LABEL"..index.."_FEMALE").."|"
	end
	
	return 0
end
]]--